@@ -2,8 +2,8 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-package Authen::SASL::EXTERNAL;
-$Authen::SASL::EXTERNAL::VERSION = '2.1700';
+package Authen::SASL::EXTERNAL 2.1900;
+
 use strict;
 use warnings;
 
